package fi.hsivonen.photobackup;

import java.util.HashMap;
import java.util.Map;
import java.util.Set;

import org.xml.sax.Attributes;
import org.xml.sax.ContentHandler;
import org.xml.sax.SAXException;

public class PhotosetFilter extends
        RootlessRestResponseContentHandlerFilter {

    private final int page;
    
    private boolean fetchNextPage = false;
    
    private final String id;

    private final FlickrEntityResolver resolver;

    private final Set<String> photoids;
    
    public PhotosetFilter(ContentHandler delegate, int page, String id, FlickrEntityResolver resolver, Set<String> photoids) {
        super(delegate);
        this.page = page;
        this.id = id;
        this.resolver = resolver;
        this.photoids = photoids;
    }

    /**
     * @see fi.hsivonen.photobackup.RootlessRestResponseContentHandlerFilter#endElement(java.lang.String, java.lang.String, java.lang.String)
     */
    @Override
    public void endElement(String uri, String localName, String qName) throws SAXException {
        if (uri == "" && (localName == "photo" || localName == "rsp" || localName == "err")) {
            super.endElement(uri, localName, qName);
        } else if (uri == "" && localName == "photoset" && fetchNextPage) {
            // dirty, dirty tail recursion
            Map<String, Object> arguments = new HashMap<String, Object>();
            arguments.put("photoset_id", id);
            arguments.put("page", new Integer(page + 1));
            System.out.println("Retrieving page " + (page + 1) + " of photoset " + id);
            resolver.callApi(new PhotosetFilter(delegate, page + 1, id, resolver, photoids), "flickr.photosets.getPhotos", arguments);
        }
    }

    /**
     * @see fi.hsivonen.photobackup.RootlessRestResponseContentHandlerFilter#startElement(java.lang.String, java.lang.String, java.lang.String, org.xml.sax.Attributes)
     */
    @Override
    public void startElement(String uri, String localName, String qName,
            Attributes atts) throws SAXException {
        if (uri == "" && localName == "photoset") {
            fetchNextPage = (page < Integer.parseInt(atts.getValue("", "pages")));
        } else if (uri == "" && (localName == "photo" || localName == "rsp" || localName == "err")) {
            if (localName == "photo") {
                photoids.add(atts.getValue("", "id"));
            }
            super.startElement(uri, localName, qName, atts);
        }
    }

    
    
}
