package fi.hsivonen.photobackup;

import java.util.HashMap;
import java.util.Map;
import java.util.Set;

import org.xml.sax.Attributes;
import org.xml.sax.ContentHandler;
import org.xml.sax.SAXException;

public class PhotosetListFilter extends
        RootlessRestResponseContentHandlerFilter {

    private final FlickrEntityResolver resolver;
    
    private String id = null;

    private final Set<String> photoids;
    
    public PhotosetListFilter(ContentHandler delegate, FlickrEntityResolver resolver, Set<String> photoids) {
        super(delegate);
        this.resolver = resolver;
        this.photoids = photoids;
    }

    /**
     * @see fi.hsivonen.photobackup.RootlessRestResponseContentHandlerFilter#endElement(java.lang.String, java.lang.String, java.lang.String)
     */
    @Override
    public void endElement(String uri, String localName, String qName) throws SAXException {
        if (uri == "" && localName == "photoset") {
            Map<String, Object> arguments = new HashMap<String, Object>();
            arguments.put("photoset_id", id);
            System.out.println("Retrieving photoset " + id);
            resolver.callApi(new PhotosetFilter(delegate, 1, id, resolver, photoids), "flickr.photosets.getPhotos", arguments);
            System.out.println("Retrieving comments for photoset " + id);
            resolver.callApi(new RootlessRestResponseContentHandlerFilter(delegate), "flickr.photosets.comments.getList", arguments);            
        }
        super.endElement(uri, localName, qName);            
    }

    /**
     * @see fi.hsivonen.photobackup.RootlessRestResponseContentHandlerFilter#startElement(java.lang.String, java.lang.String, java.lang.String, org.xml.sax.Attributes)
     */
    @Override
    public void startElement(String uri, String localName, String qName,
            Attributes atts) throws SAXException {
        if (uri == "" && localName == "photoset") {
            id = atts.getValue("", "id");
        }
        super.startElement(uri, localName, qName, atts);
    }

    
    
}
